==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Sharing" : "Chia sẻ",
    "External Storage" : "Lưu trữ ngoài",
    "Cron" : "Cron",
    "Log" : "Log",
    "Authentication error" : "Lỗi xác thực",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "Language changed" : "Ngôn ngữ đã được thay đổi",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "Unable to add user to group %s" : "Không thể thêm người dùng vào nhóm %s",
    "Unable to remove user from group %s" : "Không thể xóa người dùng từ nhóm %s",
    "Couldn't update app." : "Không thể cập nhật ứng dụng",
    "Enabled" : "Bật",
    "Saved" : "Đã lưu",
    "Email sent" : "Email đã được gửi",
    "Email saved" : "Lưu email",
    "All" : "Tất cả",
    "Please wait...." : "Xin hãy đợi...",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "__language_name__" : "__Ngôn ngữ___",
    "SSL root certificates" : "Chứng chỉ SSL root",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "More" : "hơn",
    "Less" : "ít",
    "Version" : "Phiên bản",
    "by" : "bởi",
    "Cheers!" : "Chúc mừng!",
    "Forum" : "Diễn đàn",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Bạn đã sử dụng <strong>%s </ strong> có sẵn <strong> %s </ strong>",
    "Password" : "Mật khẩu",
    "Unable to change your password" : "Không thể đổi mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Choose as profile image" : "Chọn hình ảnh như hồ sơ cá nhân",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Username" : "Tên đăng nhập",
    "Create" : "Tạo",
    "Group" : "N",
    "Default Quota" : "Hạn ngạch mặt định",
    "Unlimited" : "Không giới hạn",
    "Other" : "Khác",
    "Full Name" : "Họ và tên",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Lỗi xác thực",
    "Enabled" : "Bật",
    "Saved" : "Đã lưu",
    "Email sent" : "Email đã được gửi",
    "Email saved" : "Lưu email",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Sharing" : "Chia sẻ",
    "External Storage" : "Lưu trữ ngoài",
    "Cron" : "Cron",
    "Log" : "Log",
    "Language changed" : "Ngôn ngữ đã được thay đổi",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "Unable to add user to group %s" : "Không thể thêm người dùng vào nhóm %s",
    "Unable to remove user from group %s" : "Không thể xóa người dùng từ nhóm %s",
    "Couldn't update app." : "Không thể cập nhật ứng dụng",
    "All" : "Tất cả",
    "Please wait...." : "Xin hãy đợi...",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "__language_name__" : "__Ngôn ngữ___",
    "Unlimited" : "Không giới hạn",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "More" : "hơn",
    "Less" : "ít",
    "Version" : "Phiên bản",
    "Cheers!" : "Chúc mừng!",
    "Forum" : "Diễn đàn",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Password" : "Mật khẩu",
    "Unable to change your password" : "Không thể đổi mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Name" : "Tên",
    "Username" : "Tên đăng nhập",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "Create" : "Tạo",
    "Group" : "N",
    "Default Quota" : "Hạn ngạch mặt định",
    "Other" : "Khác",
    "Full Name" : "Họ và tên",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định"
},
"nplurals=1; plural=0;");
